==> OpenLA-0.1.3-py3-none-any.whl: openLA/data_classes/operation_count.py <==
from ..check import _is_str, _is_str_list


class OperationCount(object):
    def __init__(self, df):
        self._df = df

    @property
    def df(self):
        return self._df

    def num_users(self):
        """
        Get the number of users in the Dataframe

        :return: The number of users in the Dataframe
        :rtype: int
        """
        return self.df['userid'].nunique()

    def user_id(self):
        """
        Get the unique user ids in the Dataframe

        :return: One-dimensional array of user ids in the event_stream
        :rtype: numpy.ndarray
        """
        return self.df['userid'].unique()

    def contents_id(self):
        """
        Get the unique contents ids in the Dataframe

        :return: One-dimensional array of contents ids in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df['contentsid'].unique()

    def lecture_weeks(self):
        """
        Get the unique numbers of lecture week in the Dataframe

        :return: One-dimensional array of lecture weeks in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df['lecture'].unique()

    def operation_name(self):
        """
        Get the unique operations in the Dataframe

        :return: One-dimensional array of operation names in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df.columns.drop(['userid', 'contentsid', 'lecture']).values

    def operation_count(self, user_id=None, contents_id=None, operation_name=None):
        """
        Get the count of each operations in the Dataframe

        :param user_id: The user to count operation. If it is None, the total count of all users is returned.
        :type user_id: str or None

        :param contents_id: The contents to count operation. If it is None, the total count in all contents is returned.
        :type contents_id: str or None

        :param operation_name: The name of operation to count
        :type operation_name: str or None

        :return: If "operation_name" is None, return dictionary of the number of each operation in the Dataframe.
                 (Key: operation name, Value: The count of the operation)

                 else if "operation_name" is indicated, return the count of the operation
        :rtype: dict or int
        """
        df = self.df
        if user_id is not None:
            df = df[df['userid'] == user_id]
        if contents_id is not None:
             if _is_str(contents_id):
                 df = df[df['contentsid'] == contents_id]
             elif _is_str_list(contents_id):
                 indices = [c_id in contents_id for c_id in df['contentsid']]
                 df = df[indices]

        operation_count_dict = dict(df.drop(['userid', 'contentsid', 'lecture'], axis=1))

        if operation_name is None:
            return operation_count_dict
        else:
            assert operation_name in operation_count_dict, \
                "The operation {} does not exist".format(operation_name)
            return operation_count_dict[operation_name]

==> OpenLA-0.1.7-py3-none-any.whl: openLA/data_classes/operation_count.py <==
from ..check import _is_str, _is_str_list


class OperationCount(object):
    def __init__(self, df):
        self._df = df

    @property
    def df(self):
        return self._df

    def num_users(self):
        """
        Get the number of users in the Dataframe

        :return: The number of users in the Dataframe
        :rtype: int
        """
        return self.df['userid'].nunique()

    def user_id(self):
        """
        Get the unique user ids in the Dataframe

        :return: One-dimensional array of user ids in the event_stream
        :rtype: numpy.ndarray
        """
        return self.df['userid'].unique()

    def contents_id(self):
        """
        Get the unique contents ids in the Dataframe

        :return: One-dimensional array of contents ids in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df['contentsid'].unique()

    def lecture_weeks(self):
        """
        Get the unique numbers of lecture week in the Dataframe

        :return: One-dimensional array of lecture weeks in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df['lecture'].unique()

    def operation_name(self):
        """
        Get the unique operations in the Dataframe

        :return: One-dimensional array of operation names in the Dataframe
        :rtype: numpy.ndarray
        """
        return self.df.columns.drop(['userid', 'contentsid', 'lecture']).values

    def operation_count(self, user_id=None, contents_id=None, operation_name=None):
        """
        Get the count of specified operations

        :param user_id: The user to count operation. If it is None, the total count of all users is returned.
        :type user_id: str or None

        :param contents_id: The contents to count operation. If it is None, the total count in all contents is returned.
        :type contents_id: str or None

        :param operation_name: The name of operation to count
        :type operation_name: str or None

        :return: If "operation_name" is None, return dictionary of the number of each operation in the Dataframe.
                 (Key: operation name, Value: The count of the operation)

                 else if "operation_name" is indicated, return the count of the operation
        :rtype: dict or int
        """
        df = self.df
        if user_id is not None:
            if _is_str(user_id):
                df = df[df['userid'] == user_id]
            elif _is_str_list(user_id):
                indices = [u_id in user_id for u_id in df['userid']]
                df = df[indices]
        if contents_id is not None:
             if _is_str(contents_id):
                 df = df[df['contentsid'] == contents_id]
             elif _is_str_list(contents_id):
                 indices = [c_id in contents_id for c_id in df['contentsid']]
                 df = df[indices]

        operation_count_dict = dict(df.drop(['userid', 'contentsid', 'lecture'], axis=1).sum())

        if operation_name is None:
            return operation_count_dict
        else:
            assert operation_name in operation_count_dict, \
                "The operation {} does not exist".format(operation_name)
            return operation_count_dict[operation_name]
